library(sf)
library(dplyr)


# Spatial union
joined <- st_join(sf_bcn_sociodem, sf_pollution, join = st_intersects)

# Aggregate the values for the 100x100 polygons
aggregated <- joined %>%
  group_by(geom) %>%  
  summarize(
    # Maintain all the original columns from the socioeconomic dataset (except geom)
    across(colnames(sf_bcn_sociodem)[!colnames(sf_bcn_sociodem) %in% "geom"], ~first(.x)),
    
    # Aggregate the mean of NO2 from the 20x20 polygons (from the pollution diagnosis)
    mean_pollutant = mean(var1.pred, na.rm = TRUE),
    
    # Maintain the geometry from the 100x100 polygon grid (socieconomic dataset)
    geom = first(geom)
  )

# Ensure that the result is a valid sf object
sf_bcn_socioPollution <- st_as_sf(aggregated)

# Maintain the original coordinate system
st_crs(sf_bcn_socioPollution) <- st_crs(sf_bcn_sociodem)

#mapview::mapview(result_sf, zcol = 'mean_pollutant')

