library(ggplot2)

# Function to create and save binned bar plots for multiple variables
plot_binned_data <- function(data, var_breaks_list, output_dir = "binnedPlots") {
  if (!dir.exists(output_dir)) {
    dir.create(output_dir)
  }
  
  # Loop over each variable in the list
  for (var_name in names(var_breaks_list)) {
    breaks <- var_breaks_list[[var_name]]
    
    # Generate labels dynamically based on breaks
    labels <- paste0(head(breaks, -1), "-", tail(breaks, -1))
    labels[length(labels)] <- paste0(">", breaks[length(breaks) - 1])  # Last category
    
    # Create the binned variable
    data$bin_group <- cut(data[[var_name]], breaks = breaks, labels = labels, include.lowest = TRUE)
    
    # Generate the plot
    p <- ggplot(data, aes(x = bin_group)) + 
      geom_bar(fill = "blue") +
      labs(title = paste("Binned Data Plot for", var_name), x = "Binned Ranges") +
      theme(axis.text.x = element_text(angle = 45, hjust = 1))
    
    # Save the plot as a .jpg file
    output_path <- file.path(output_dir, paste0(var_name, "_binned_plot.jpg"))
    ggsave(output_path, plot = p, width = 8, height = 6, dpi = 300)
    
    print(paste("Saved plot for", var_name, "at", output_path))
  }
}



var_breaks_list <- list(
  p_t = c(0, 10, 20, 30, 40, 50, 100, 500, 1000, Inf),
  hog = c(0, 2.5, 5, 7.5, 10, 20, 30, 100, 200, Inf),
  p_ed_00_04_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_00_04_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_00_14_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_15_24_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 45, Inf),
  p_ed_25_44_h = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 100, 150, Inf),
  p_ed_45_64_h = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 100, Inf),
  p_ed_65_79_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 50, Inf),
  p_ed_80_mas_h = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_00_14_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  p_ed_15_24_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 45, Inf),
  p_ed_25_44_m = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 100, Inf),
  p_ed_45_64_m = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 100, Inf),
  p_ed_65_79_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 15, 30, 45, Inf),
  p_ed_80_mas_m = c(0, 0.25, 0.5, 0.75, 1, 2, 3, 5, 7.5, 10, 20, Inf),
  inm_pobr = c(0, 1, 2, 3, 4, 5, 10, 30, 50, 75, 150, 300, Inf),
  renta_tit_disp = c(0, 10000, 15000, 20000, 25000, 30000, 35000, 40000, 50000, Inf),
  salario_act = c(0, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, Inf)
)


plot_binned_data(combined_cat_reduced, var_breaks_list)




