# Load necessary libraries
library(ggplot2)
library(patchwork)
library(cowplot)

# Function to generate and save combined plots
create_box_violin <- function(data, variables, folder = "BoxViolin") {
  # Create the folder if it does not exist
  if (!dir.exists(folder)) {
    dir.create(folder)
  }
  
  # Iterate over the list of variables
  for (var in variables) {
    # Create the boxplot
    boxplot_fig <- ggplot(data, aes(x = '', y = .data[[var]])) + 
      geom_boxplot(fill = "slateblue", alpha = 0.5) +
      labs(title = paste("Boxplot of", var), y = var) +
      theme_minimal()
    
    # Create the violin plot
    violin_fig <- ggplot(data, aes(x = '', y = .data[[var]])) + 
      geom_violin(fill = "lightblue", color = "black", alpha = 0.5) +
      labs(title = paste("Violin Plot of", var), y = var) +
      theme_minimal()
    
    # Combine both plots
    combined_plot <- plot_grid(boxplot_fig, violin_fig)
    
    # Save the image in the specified folder
    file_path <- file.path(folder, paste0(var, ".jpg"))
    ggsave(file_path, combined_plot, width = 8, height = 4, dpi = 300)
    
    print(paste("Plot saved:", file_path))
  }
}

# Call the function with the variables to plot
variables_to_plot <- c("p_ed_45_64_h_16", "p_t", "hog", "p_ed_00_04_h", "p_ed_00_04_m", "p_ed_00_14_h", "p_ed_15_24_h", "p_ed_25_44_h", "p_ed_45_64_h", "p_ed_65_79_h", "p_ed_80_mas_h", "p_ed_00_14_m", "p_ed_15_24_m", "p_ed_25_44_m", "p_ed_45_64_m", "p_ed_65_79_m", "p_ed_80_mas_m", "inm_pobr", "renta_tit_disp", "salario_act")
create_box_violin(combined_catalunya, variables_to_plot)


