#!/usr/bin/env Rscript


# Script para combinar todos los CSVs en un directorio
library(data.table)
library(dplyr)

# Directorio donde están los CSVs
# Cambiar esto al path correcto
csv_dir <- "/esarchive/scratch/acantare/Unica360_analysis/results"

# Obtener lista de archivos CSV
csv_files <- list.files(path = csv_dir, 
                        pattern = "*.csv", 
                        full.names = TRUE)

# Leer y combinar todos los CSVs
combined_data <- rbindlist(
  lapply(csv_files, function(file) {
    # Leer cada archivo
    df <- fread(file)
    # Agregar nombre del archivo como columna si es necesario
    df$source_file <- basename(file)
    return(df)
  }),
  fill = TRUE  # Maneja el caso de columnas diferentes entre archivos
)

# Guardar el resultado
output_file <- "combined_catalunya.csv"
fwrite(combined_data, output_file)

# Imprimir resumen
cat("Archivos combinados:", length(csv_files), "\n")
cat("Total de filas:", nrow(combined_data), "\n")
cat("Total de columnas:", ncol(combined_data), "\n")
cat("Resultado guardado en:", output_file, "\n")




